summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KCModule.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KCModule.java')
-rw-r--r--kdejava/koala/org/kde/koala/KCModule.java94
1 files changed, 47 insertions, 47 deletions
diff --git a/kdejava/koala/org/kde/koala/KCModule.java b/kdejava/koala/org/kde/koala/KCModule.java
index 80ceb4cb..3f26535e 100644
--- a/kdejava/koala/org/kde/koala/KCModule.java
+++ b/kdejava/koala/org/kde/koala/KCModule.java
@@ -21,28 +21,28 @@ import org.kde.qt.TQWidget;
that contains at one factory function like this:
<pre>
#include <kgenericfactory.h>
- typedef KGenericFactory<YourKCModule, TQWidget> YourKCModuleFactory;
- K_EXPORT_COMPONENT_FACTORY( yourLibName, YourKCModuleFactory("name_of_the_po_file") );
+ typedef KGenericFactory<YourTDECModule, TQWidget> YourTDECModuleFactory;
+ K_EXPORT_COMPONENT_FACTORY( yourLibName, YourTDECModuleFactory("name_of_the_po_file") );
</pre>
The parameter "name_of_the_po_file" has to correspond with the messages target
that you created in your Makefile.am.
See http://developer.kde.org/documentation/other/kcm_howto.html
for more detailed documentation.
- See {@link KCModuleSignals} for signals emitted by KCModule
+ See {@link TDECModuleSignals} for signals emitted by TDECModule
@author Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
@short The base class for control center modules.
*/
-public class KCModule extends TQWidget {
- protected KCModule(Class dummy){super((Class) null);}
+public class TDECModule extends TQWidget {
+ protected TDECModule(Class dummy){super((Class) null);}
/**
An enumeration type for the buttons used by this module.
You should only use Help, Default and Apply. The rest is obsolete.
@short An enumeration type for the buttons used by this module.
- @see KCModule#buttons
+ @see TDECModule#buttons
@see @see
- @see KCModule#setButtons
+ @see TDECModule#setButtons
*/
public static final int Help = 1;
public static final int Default = 2;
@@ -54,41 +54,41 @@ public class KCModule extends TQWidget {
public native TQMetaObject metaObject();
public native String className();
- public KCModule(TQWidget parent, String name, String[] args) {
+ public TDECModule(TQWidget parent, String name, String[] args) {
super((Class) null);
- newKCModule(parent,name,args);
+ newTDECModule(parent,name,args);
}
- private native void newKCModule(TQWidget parent, String name, String[] args);
- public KCModule(TQWidget parent, String name) {
+ private native void newTDECModule(TQWidget parent, String name, String[] args);
+ public TDECModule(TQWidget parent, String name) {
super((Class) null);
- newKCModule(parent,name);
+ newTDECModule(parent,name);
}
- private native void newKCModule(TQWidget parent, String name);
- public KCModule(TQWidget parent) {
+ private native void newTDECModule(TQWidget parent, String name);
+ public TDECModule(TQWidget parent) {
super((Class) null);
- newKCModule(parent);
+ newTDECModule(parent);
}
- private native void newKCModule(TQWidget parent);
- public KCModule() {
+ private native void newTDECModule(TQWidget parent);
+ public TDECModule() {
super((Class) null);
- newKCModule();
+ newTDECModule();
}
- private native void newKCModule();
- public KCModule(TDEInstanceInterface instance, TQWidget parent, String[] args) {
+ private native void newTDECModule();
+ public TDECModule(TDEInstanceInterface instance, TQWidget parent, String[] args) {
super((Class) null);
- newKCModule(instance,parent,args);
+ newTDECModule(instance,parent,args);
}
- private native void newKCModule(TDEInstanceInterface instance, TQWidget parent, String[] args);
- public KCModule(TDEInstanceInterface instance, TQWidget parent) {
+ private native void newTDECModule(TDEInstanceInterface instance, TQWidget parent, String[] args);
+ public TDECModule(TDEInstanceInterface instance, TQWidget parent) {
super((Class) null);
- newKCModule(instance,parent);
+ newTDECModule(instance,parent);
}
- private native void newKCModule(TDEInstanceInterface instance, TQWidget parent);
- public KCModule(TDEInstanceInterface instance) {
+ private native void newTDECModule(TDEInstanceInterface instance, TQWidget parent);
+ public TDECModule(TDEInstanceInterface instance) {
super((Class) null);
- newKCModule(instance);
+ newTDECModule(instance);
}
- private native void newKCModule(TDEInstanceInterface instance);
+ private native void newTDECModule(TDEInstanceInterface instance);
/**
Load the configuration data into the module.
The load method sets the user interface elements of the
@@ -99,9 +99,9 @@ public class KCModule extends TQWidget {
This happens when the user clicks the "Reset" button in the control
center, to undo all of his changes and restore the currently valid
settings.
- If you use KConfigXT, loading is taken care of automatically and
+ If you use TDEConfigXT, loading is taken care of automatically and
you do not need to do it manually. However, if you for some reason reimplement it and
- also are using KConfigXT, you must call this function otherwise the loading of KConfigXT
+ also are using TDEConfigXT, you must call this function otherwise the loading of TDEConfigXT
options will not work.
@short Load the configuration data into the module.
*/
@@ -115,9 +115,9 @@ public class KCModule extends TQWidget {
KSettings.Dialog modules where the updating is taken care of by
KSettings.Dispatcher.
save is called when the user clicks "Apply" or "Ok".
- If you use KConfigXT, saving is taken care off automatically and
+ If you use TDEConfigXT, saving is taken care off automatically and
you do not need to load manually. However, if you for some reason reimplement it and
- also are using KConfigXT, you must call this function, otherwise the saving of KConfigXT
+ also are using TDEConfigXT, you must call this function, otherwise the saving of TDEConfigXT
options will not work. Call it at the very end of your reimplementation, to avoid
changed() signals getting emitted when you modify widgets.
@short Save the configuration data.
@@ -127,9 +127,9 @@ public class KCModule extends TQWidget {
Sets the configuration to sensible default values.
This method is called when the user clicks the "Default"
button. It should set the display to useful values.
- If you use KConfigXT, you do not have to reimplement this function since
+ If you use TDEConfigXT, you do not have to reimplement this function since
the fetching and settings of default values is done automatically. However, if you
- reimplement and also are using KConfigXT, remember to call the base function at the
+ reimplement and also are using TDEConfigXT, remember to call the base function at the
very end of your reimplementation.
@short Sets the configuration to sensible default values.
*/
@@ -169,7 +169,7 @@ public class KCModule extends TQWidget {
The return value is a value or'ed together from
the Button enumeration type.
@short Indicate which buttons will be used.
- @see KCModule#setButtons
+ @see TDECModule#setButtons
*/
public native int buttons();
/**
@@ -181,7 +181,7 @@ public class KCModule extends TQWidget {
customized message. If none has been set, a default message
will be used.
@short Get the RootOnly message for this module.
- @see KCModule#setRootOnlyMsg
+ @see TDECModule#setRootOnlyMsg
*/
public native String rootOnlyMsg();
/**
@@ -191,26 +191,26 @@ public class KCModule extends TQWidget {
appear (for example if it has already one). This function
tells KControl if a RootOnly message should be shown
@short Tell if KControl should show a RootOnly message when run as a normal user.
- @see KCModule#setUseRootOnlyMsg
+ @see TDECModule#setUseRootOnlyMsg
*/
public native boolean useRootOnlyMsg();
public native TDEInstanceInterface instance();
/**
- @return a list of @ref KConfigDialogManager's in use, if any.
+ @return a list of @ref TDEConfigDialogManager's in use, if any.
@short
*/
// const TQPtrList<KConfigDialogManager>& configs(); >>>> NOT CONVERTED
/**
- Adds a KConfigskeleton <code>config</code> to watch the widget <code>widget</code>
+ Adds a TDEConfigskeleton <code>config</code> to watch the widget <code>widget</code>
This function is useful if you need to handle multiple configuration files.
- @param config the KConfigSkeleton to use
+ @param config the TDEConfigSkeleton to use
@param widget the widget to watch
- @return a pointer to the KConfigDialogManager in use
+ @return a pointer to the TDEConfigDialogManager in use
- @short Adds a KConfigskeleton <code>config</code> to watch the widget <code>widget</code>
+ @short Adds a TDEConfigskeleton <code>config</code> to watch the widget <code>widget</code>
*/
- // KConfigDialogManager* addConfig(KConfigSkeleton* arg1,TQWidget* arg2); >>>> NOT CONVERTED
+ // TDEConfigDialogManager* addConfig(TDEConfigSkeleton* arg1,TQWidget* arg2); >>>> NOT CONVERTED
/**
Sets the tquick help.
@short Sets the tquick help.
@@ -224,7 +224,7 @@ public class KCModule extends TQWidget {
in kcmshell this will show an "Ok", "Apply" and "Cancel" button
If Apply is not specified, kcmshell will show a "Close" button.
@short Sets the buttons to display.
- @see KCModule#buttons
+ @see TDECModule#buttons
*/
protected native void setButtons(int btn);
/**
@@ -233,7 +233,7 @@ public class KCModule extends TQWidget {
corresponding desktop file contains the line X-TDE-RootOnly=true.
If no message is set, a default one will be used.
@short Sets the RootOnly message.
- @see KCModule#rootOnlyMsg
+ @see TDECModule#rootOnlyMsg
*/
protected native void setRootOnlyMsg(String msg);
/**
@@ -241,7 +241,7 @@ public class KCModule extends TQWidget {
Following the value of <code>on</code>, the RootOnly message will be
shown or not.
@short Change whether or not the RootOnly message should be shown.
- @see KCModule#useRootOnlyMsg
+ @see TDECModule#useRootOnlyMsg
*/
protected native void setUseRootOnlyMsg(boolean on);
/**
@@ -191,26 +191,26 @@ public class KCModule extends TQWidget {
*/
- // const TQPtrList<KConfigDialogManager>& configs(); >>>> NOT CONVERTED
+ // const TQPtrList<TDEConfigDialogManager>& configs(); >>>> NOT CONVERTED
/**